Page 65 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 65

Home

    controlled by forces outside himself and can do nothing
    to improve his lot in life. Therefore, he needed a king or
    leader to guide and control him. In this stagnant world,
    with no hope of progress, men must be herded into a
    collective mass, a bee hive, and controlled.

    This pagan view was dominant for nearly 6,000 years
    of recorded history with the result that hunger and famine
    remained a common foe for most of the inhabitants of

    earth. Progress was so slow that, until the time of George
    Washington, the best thing that man could come up with
    for transportation was the horse drawn coach, and that
    could only be afforded by the rich. Then something
    amazing happened. The Old World pagan concepts were
    rejected, resulting in more progress toward a better way
    of life in less than 200 years than the accumulated

    progress of 6,000 years.

    The events leading up to this quantum leap forward
    actually began on the American Continent as far back as
    1660. It was during this time that the colonies began to
    rebel against the pagan Old World View of a planned

    economy.
    Charles II had signed an act allowing the American
    Colonies to ship cotton, lumber, tobacco, and other
    products to England, but only to England, nowhere else.
    The colonists needed sugar and molasses from the West
    Indies (Cuba). Therefore, they just ignored the King's
    decree and kept on trading wool and tobacco for sugar
    and molasses. A few of the traders' ships were sunk by

    60

    The Secret Side of History